.. -*- coding: utf-8 -*-
.. :Progetto:  SoL
.. :Creato:    mar 28 gen 2014 10:53:23 CET
.. :Autore:    Lele Gaifax <lele@metapensiero.it>
.. :Licenza:   GNU General Public License version 3 or later
..

===========
 Appendici
===========

.. toctree::

   regole
   dedica
   sviluppo
